MethodChannelBluetoothConnect class

MethodChannel 实现

Inheritance

Properties

connectionEventChannel EventChannel
final
connectionState Stream<String>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanEventChannel EventChannel
final
scanResults Stream<List<BluetoothDevice>>
no setteroverride

Methods

connect(String deviceId) Future<void>
override
disconnect() Future<void>
override
isAvailable() Future<bool>
override
isOn() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScan({Duration timeout = const Duration(seconds: 10)}) Future<void>
override
stopScan() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited