BluetoothConnectPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BluetoothConnectPlatform
Implementers

Constructors

BluetoothConnectPlatform()

Properties

connectionState Stream<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanResults Stream<List<BluetoothDevice>>
no setter

Methods

connect(String deviceId) Future<void>
disconnect() Future<void>
isAvailable() Future<bool>
isOn() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScan({Duration timeout = const Duration(seconds: 10)}) Future<void>
stopScan() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BluetoothConnectPlatform
getter/setter pair