BluetoothDevice class

BLE 设备信息模型

Constructors

BluetoothDevice({required String id, required String name, required int rssi})
const
BluetoothDevice.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
设备唯一标识(Android 多为 MAC,iOS 为系统 UUID)
final
name String
广播名称,可能为空
final
rssi int
信号强度(RSSI)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited